Skip to contents

This function checks for stationarity of the AR(p) coefficients. Stationarity is determined based on the roots of the autoregressive polynomial. For a stationary AR(p) process, all the roots of this autoregressive polynomial must lie inside the unit circle in the complex plane.

Usage

CheckARCoef(coef)

Arguments

coef

Numeric vector. Autoregressive coefficients.

See also

Other Simulation of Autoregressive Data Functions: CheckVARCoef(), SimARCoef(), SimAR(), SimMVN(), SimPD(), SimVARCoef(), SimVARExo(), SimVARZIPExo(), SimVARZIP(), SimVAR(), SimVariance(), YXExo(), YX()

Author

Ivan Jacob Agaloos Pesigan

Examples

set.seed(42)
(coef <- SimARCoef(p = 2))
#>            [,1]
#> [1,] -0.3849488
#> [2,]  0.5948057
CheckARCoef(coef = coef)
#> [1] TRUE