This function checks for stationarity of the AR(p) coefficients. Stationarity is determined based on the roots of the autoregressive polynomial. For a stationary AR(p) process, all the roots of this autoregressive polynomial must lie inside the unit circle in the complex plane.
See also
Other Simulation of Autoregressive Data Functions:
CheckVARCoef(),
SimARCoef(),
SimAR(),
SimMVN(),
SimPD(),
SimVARCoef(),
SimVARExo(),
SimVARZIPExo(),
SimVARZIP(),
SimVAR(),
SimVariance(),
YXExo(),
YX()