The function checks if all the eigenvalues have moduli (absolute values) less than 1. If all eigenvalues have moduli less than 1, it indicates that the VAR process is stable and, therefore, stationary. If any eigenvalue has a modulus greater than or equal to 1, it indicates that the VAR process is not stable and, therefore, non-stationary.
Arguments
- coef
Numeric matrix. Coefficient matrix with dimensions
kby(k * p). Eachkbykblock corresponds to the coefficient matrix for a particular lag.
See also
Other Simulation of Autoregressive Data Functions:
CheckARCoef(),
SimARCoef(),
SimAR(),
SimMVN(),
SimPD(),
SimVARCoef(),
SimVARExo(),
SimVARZIPExo(),
SimVARZIP(),
SimVAR(),
SimVariance(),
YXExo(),
YX()
Examples
set.seed(42)
(coef <- SimVARCoef(k = 3, p = 2))
#> [,1] [,2] [,3] [,4] [,5] [,6]
#> [1,] -0.8299143 -0.59172421 0.3160931 0.1196792 -0.4116841 -0.4670195
#> [2,] 0.4478317 -0.43004167 0.8690710 0.6294415 0.5906853 -0.8226202
#> [3,] 0.3190983 0.02594328 0.4671797 -0.5589469 0.3477687 -0.6471376
CheckVARCoef(coef = coef)
#> [1] TRUE